Deletes only the configured bluertopo package cache after path safeguards.
Usage
bluertopo_cache_clear(
cache_dir = bluertopo_cache_dir(),
confirm = interactive()
)Deletes only the configured bluertopo package cache after path safeguards.
bluertopo_cache_clear(
cache_dir = bluertopo_cache_dir(),
confirm = interactive()
)